@@ -65,6 +65,12 @@ LOG_URI = (
     'logs files are not written to Amazon S3 from the master node '
     'and are lost if the master node terminates.</p>')
 
+LOG_ENCRYPTION_KMS_KEY_ID = (
+    '<p> Specifies the KMS Id utilized for log encryption. If a value is '
+    'not provided, log files will be encrypted by default encryption method '
+    'AES-256. This attribute is only available with EMR version 5.30.0 and later, '
+    'excluding EMR 6.0.0.</p>')
+
 SERVICE_ROLE = (
     '<p>Specifies an IAM service role, which Amazon EMR requires to call other AWS services '
     'on your behalf during cluster operation. This parameter '
@@ -445,3 +451,13 @@ STEP_CONCURRENCY_LEVEL = (
     'This command specifies the step concurrency level of the cluster.'
     'Default is 1 which is non-concurrent.'
 )
+
+MANAGED_SCALING_POLICY = (
+    '<p>Managed scaling policy for an Amazon EMR cluster. The policy '
+    'specifies the limits for resources that can be added or terminated '
+    'from a cluster. You can specify the ComputeLimits which include '
+    'the MaximumCapacityUnits, MinimumCapacityUnits, '
+    'MaximumOnDemandCapacityUnits and UnitType. For an '
+    'InstanceFleet cluster, the UnitType must be InstanceFleetUnits. For '
+    'InstanceGroup clusters, the UnitType can be either VCPU or Instances.</p>'
+)
